<?php

namespace backend\controllers;

use Yii;
use backend\models\Codes;
use backend\models\CodesSearch;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;
use yii\filters\AccessControl;
use yii\web\Session;

/**
 * CodesController implements the CRUD actions for Codes model.
 */
class CodesController extends Controller
{
    public function behaviors()
    {
        return [
            'access' => [
                'class' => AccessControl::className(),
                'rules' => [
                    [
                        'actions' => ['test'],
                        'allow' => true,
                    ],
                    [
                        'actions' => ['update', 'index','delete','view','create'],
                        'allow' => true,
                        'roles' => ['@'],
                    ],
                ],
            ],
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'delete' => ['post'],
                ],
            ],
        ];
    }
 public function beforeAction($action)
    {
        if (!parent::beforeAction($action)) {
            return false;
        }
        // Check only when the user is logged in
        if ( !Yii::$app->user->isGuest)  { 
            
            $time=\Yii::$app->session->get('userSessionTimeout');
            
            if ($time < time()) {
                Yii::$app->user->logout();
            } else {
                \Yii::$app->session->set('userSessionTimeout',time() + Yii::$app->params['sessionTimeoutSeconds']);      
                return true; 
            }
        } else {
            return true;
        }
    }
    /**
     * Lists all Codes models.
     * @return mixed
     */
    public function actionIndex()
    {
        $searchModel = new CodesSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);

        return $this->render('index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Displays a single Codes model.
     * @param integer $id
     * @return mixed
     */
    public function actionView($id)
    {
        return $this->render('view', [
            'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new Codes model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate()
    {
        $model = new Codes();       
        if ($model->load(Yii::$app->request->post())) {
            $model->Created_at=date('Y-m-d H:i:s');
            $model->Updated_at=date('Y-m-d H:i:s');
            $model->UserId_fk=Yii::$app->user->identity->UserId;
           if($model->save())  {     
                  Yii::$app->session->setFlash('success','Code Successfully Added');
                return $this->redirect(['index']);
           // return $this->redirect(['view', 'id' => $model->CodeId]);
           }else{
               return $this->render('create', [
                'model' => $model,
                ]);
           }
        } else {
            return $this->render('create', [
                'model' => $model,
            ]);
        }
    }

    /**
     * Updates an existing Codes model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     */
    public function actionUpdate($id)
    {
        $model = $this->findModel($id);

        if ($model->load(Yii::$app->request->post()) && $model->save()) {
             Yii::$app->session->setFlash('success','Code Successfully Updated');
                return $this->redirect(['index']);
            //return $this->redirect(['view', 'id' => $model->CodeId]);
        } else {
            return $this->render('update', [
                'model' => $model,
            ]);
        }
    }

    /**
     * Deletes an existing Codes model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     */
    public function actionDelete($id)
    {
        $model=$this->findModel($id);
         if(!empty($model)) {
              $model->Status="TRASH";
               if($model->save(false)){ 
                    Yii::$app->session->setFlash('success','Code Successfully Deleted');
                    return $this->redirect(['index']);
               }else{
                    return $this->redirect(['index']);
               }
         }
        return $this->redirect(['index']);
       // $this->findModel($id)->delete();

       // return $this->redirect(['index']);
    }

    /**
     * Finds the Codes model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return Codes the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = Codes::findOne($id)) !== null) {
            return $model;
        } else {
            throw new NotFoundHttpException('The requested page does not exist.');
        }
    }
}
