<?php

namespace backend\controllers;

use Yii;
use backend\models\Orders;
use backend\models\OrdersSearch;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;
use yii\filters\AccessControl;
use yii\web\Session;
/**
 * OrdersController implements the CRUD actions for Orders model.
 */
class OrdersController extends Controller
{
    public function behaviors()
    {
        return [
               'access' => [
                'class' => AccessControl::className(),
                'rules' => [
                    [
                        'actions' => ['test'],
                        'allow' => true,
                    ],
                    [
                        'actions' => ['deletepermanent','links','trash','cancelled','move','csv','update', 'index','delete','view','create','buy','waiting','payment','completed','delayed','toship','presale','soldout','problem','bought'],
                        'allow' => true,
                        'roles' => ['@'],
                    ],
                ],
            ],
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'delete' => ['post'],
                ],
            ],
        ];
    }
 public function beforeAction($action)
    {
        if (!parent::beforeAction($action)) {
            return false;
        }
        // Check only when the user is logged in
        if ( !Yii::$app->user->isGuest)  { 
            
            $time=\Yii::$app->session->get('userSessionTimeout');
            
            if ($time < time()) {
                Yii::$app->user->logout();
            } else {
                \Yii::$app->session->set('userSessionTimeout',time() + Yii::$app->params['sessionTimeoutSeconds']);      
                return true; 
            }
        } else {
            return true;
        }
    }
    /**
     * Lists all Orders models.
     * @return mixed
     */
    public function actionCsv($status){
      $action=$status;
        if($action=="buy"){
            $search='TO BUY';          
        }elseif($action=="waiting"){
            $search='WAITING PAYMENT';      
        }elseif($action=="payment"){
            $search='PAYMENT RECEIVED';      
        }elseif($action=="completed"){
            $search='COMPLETED';      
        }elseif($action=="delayed"){
            $search='DELAYED';       
        }elseif($action=="toship"){
            $search='TO SHIP';        
        }elseif($action=="presale"){
            $search='PRESALE';       
        }elseif($action=="soldout"){
            $search='SOLD OUT';       
        }elseif($action=="problem"){
            $search='PROBLEM';       
        }elseif($action=="bought"){
            $search='BOUGHT';      
        }elseif($action=="cancelled"){
            $search='CANCELLED';      
        }elseif($action=="links"){
            $search='LINKS TO ADD';      
        }elseif($action=="trash"){
            $search='TRASH';      
        }elseif($action=="index"){
            $search='all';      
        }else{
            $this->redirect(["orders/"]);
            exit;
        }
        
        if($search!="all") {
           $models = Orders::find()->where(['Status' => $search])->orderBy(['EventDate' => SORT_ASC])->all();  
        }else{
            $models = Orders::find()->where('Status != :status', [':status' => 'DELETED'])->orderBy(['EventDate' => SORT_ASC])->all();  
        }
          // $models = Orders::find()->where(['Status' => $search])->orderBy(['OrderDate' => SORT_DESC])->all();  
           if(!empty($models)) {
               
            $fileName = "Orders-".time().'.csv';
            header("Cache-Control: must-revalidate, post-check=0, pre-check=0");
            header('Content-Description: File Transfer');
            header("Content-type: text/csv");
            header("Content-Disposition: attachment; filename={$fileName}");
            header("Expires: 0");
            header("Pragma: public");
            $fh = @fopen( 'php://output', 'w' ); 
               
               $headerDisplayed = false;    
               foreach($models as $model){
                   $single=array();
                   $single['Order Date']=$model->OrderDate;
                   $single['Order#']=$model->OrderMainId;
                   $single['Quantity']=$model->Quantity;
                   $single['Event']=$model->Event;
                   $single['venue']=$model->Venue;
                   $single['Section']=$model->Section;
                   $single['Row']=$model->Row;
                   $single['Event Data']=$model->EventDate;
                   if(!empty($model->Cost)) {
                       $single['Cost']='$'.$model->Cost;
                   }else{
                   $single['Cost']=$model->Cost;
                   }
                   if(Yii::$app->user->identity->Role!='user') {
                    $single['Sale Price']='$'.$model->SalePrice;
                    if(!empty($model->Profit)) {
                     $single['Profit']='$'.$model->Profit;
                    }else{
                    $single['Profit']=$model->Profit;
                    }
                   }
                   $single['Source']=$model->Source;
                   if(!empty($model->CreditCard)) {
                       if($model->CreditCard=="OTHER") {
                        $single['Credit Card']=$model->Othertype;    
                       }else{
                        $single['Credit Card']=$model->CreditCard; 
                       }
                   }else{
                   $single['Credit Card']=$model->CreditCard;                 
                   }
                   $single['Link']=$model->Link;
                   $single['Notes']=$model->Notes;
                   $single['Status']=$model->Status;
                   $data=$single;               
                    if ( !$headerDisplayed ) {                   
                        fputcsv($fh, array_keys($data));
                        $headerDisplayed = true;
                    }
                    fputcsv($fh, $data);                  
               }
                fclose($fh);           
                exit;
           }
        
    }
    public function actionDeletepermanent(){
        $status="DELETED";
        foreach($_REQUEST['id'] as $id){            
                $model = Orders::find()
                ->where(['OrderId' => $id])
                ->one(); 
                $model->Status=$status;
                $model->Updated_at=date('Y-m-d H:i:s');
                $model->save(false);                
        }
        echo "succes";
        die;       
    }
    public function actionMove(){
        $status=trim($_REQUEST['status']);
        foreach($_REQUEST['id'] as $id){            
                $model = Orders::find()
                ->where(['OrderId' => $id])
                ->one(); 
                $model->Status=$status;
                $model->Updated_at=date('Y-m-d H:i:s');
                $model->save(false);                
        }
        echo "succes";
        die;       
    }
    public function actionTrash()
    {
    \Yii::$app->session->set('user.backprocress','trash');
  
        $searchModel = new OrdersSearch();
        $dataProvider = $searchModel->searchTrash(Yii::$app->request->queryParams);
    \Yii::$app->session->set('user.queryparam',Yii::$app->request->queryParams);
        return $this->render('index-chnaged', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }
    public function actionLinks()
    {
    \Yii::$app->session->set('user.backprocress','links');
  
        $searchModel = new OrdersSearch();
        $dataProvider = $searchModel->searchLinks(Yii::$app->request->queryParams);
    \Yii::$app->session->set('user.queryparam',Yii::$app->request->queryParams);
        return $this->render('index-chnaged', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }
     public function actionIndex()
    {
        \Yii::$app->session->set('user.backprocress','index');
        $searchModel = new OrdersSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);
        \Yii::$app->session->set('user.queryparam',Yii::$app->request->queryParams);
        return $this->render('index-chnaged', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }
public function actionCancelled()
    {
    \Yii::$app->session->set('user.backprocress','cancelled');
  
        $searchModel = new OrdersSearch();
        $dataProvider = $searchModel->searchcancelled(Yii::$app->request->queryParams);
    \Yii::$app->session->set('user.queryparam',Yii::$app->request->queryParams);
        return $this->render('index-chnaged', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }
    public function actionBuy()
    {
        \Yii::$app->session->set('user.backprocress','buy');
        $searchModel = new OrdersSearch();
        $dataProvider = $searchModel->searchbuy(Yii::$app->request->queryParams);
        \Yii::$app->session->set('user.queryparam',Yii::$app->request->queryParams);
           
        return $this->render('index-chnaged', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }
    public function actionWaiting()
    {
         \Yii::$app->session->set('user.backprocress','waiting');
        $searchModel = new OrdersSearch();
        $dataProvider = $searchModel->searchwaiting(Yii::$app->request->queryParams);
        \Yii::$app->session->set('user.queryparam',Yii::$app->request->queryParams);
        return $this->render('index-chnaged', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }
     public function actionPayment()
    {
           \Yii::$app->session->set('user.backprocress','payment');
        $searchModel = new OrdersSearch();
        $dataProvider = $searchModel->searchpayment(Yii::$app->request->queryParams);
        \Yii::$app->session->set('user.queryparam',Yii::$app->request->queryParams);
        return $this->render('index-chnaged', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }
     public function actionCompleted()
    {
          \Yii::$app->session->set('user.backprocress','completed');
        $searchModel = new OrdersSearch();
        $dataProvider = $searchModel->searchcompleted(Yii::$app->request->queryParams);
        \Yii::$app->session->set('user.queryparam',Yii::$app->request->queryParams);
        return $this->render('index-chnaged', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }
    public function actionDelayed()
    {
        \Yii::$app->session->set('user.backprocress','delayed');
        $searchModel = new OrdersSearch();
        $dataProvider = $searchModel->searchdelayed(Yii::$app->request->queryParams);
        \Yii::$app->session->set('user.queryparam',Yii::$app->request->queryParams);
        return $this->render('index-chnaged', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }
    
    public function actionToship()
    {
        \Yii::$app->session->set('user.backprocress','toship');
        $searchModel = new OrdersSearch();
        $dataProvider = $searchModel->searchtoship(Yii::$app->request->queryParams);
        \Yii::$app->session->set('user.queryparam',Yii::$app->request->queryParams);
        return $this->render('index-chnaged', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }
     public function actionPresale()
    {
         \Yii::$app->session->set('user.backprocress','presale');
        $searchModel = new OrdersSearch();
        $dataProvider = $searchModel->searchpresale(Yii::$app->request->queryParams);
        \Yii::$app->session->set('user.queryparam',Yii::$app->request->queryParams);
        return $this->render('index-chnaged', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }
     public function actionSoldout()
    {
         \Yii::$app->session->set('user.backprocress','soldout');
        $searchModel = new OrdersSearch();
        $dataProvider = $searchModel->searchsoldout(Yii::$app->request->queryParams);
        \Yii::$app->session->set('user.queryparam',Yii::$app->request->queryParams);
        return $this->render('index-chnaged', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }
     public function actionProblem()
    {
          \Yii::$app->session->set('user.backprocress','problem');
        $searchModel = new OrdersSearch();
        $dataProvider = $searchModel->searchproblem(Yii::$app->request->queryParams);
        \Yii::$app->session->set('user.queryparam',Yii::$app->request->queryParams);
        return $this->render('index-chnaged', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }
      public function actionBought()
    {
           \Yii::$app->session->set('user.backprocress','bought');
        $searchModel = new OrdersSearch();
        $dataProvider = $searchModel->searchbought(Yii::$app->request->queryParams);
        \Yii::$app->session->set('user.queryparam',Yii::$app->request->queryParams);
        return $this->render('index', [
            'searchModel' => $searchModel,
            'dataProvider' => $dataProvider,
        ]);
    }
    /**
     * Displays a single Orders model.
     * @param integer $id
     * @return mixed
     */
    public function actionView($id)
    {
        return $this->render('view', [
            'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new Orders model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate()
    {
        $model = new Orders();

        if ($model->load(Yii::$app->request->post()) && $model->save()) {
               Yii::$app->session->setFlash('success','Order Successfully Added');
               $back=\Yii::$app->session->get('user.backprocress');
               
                 if(!empty($back)) {
                       return $this->redirect([$back]);
                 }else{
                      return $this->redirect(['buy']);
                 }
           // return $this->redirect(['view', 'id' => $model->OrderId]);
        } else {
            return $this->render('create', [
                'model' => $model,
            ]);
        }
    }

    /**
     * Updates an existing Orders model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     */
    public function actionUpdate($id)
    {
        $model = $this->findModel($id);
        $model->scenario = 'update';
        if ($model->load(Yii::$app->request->post())) {
            $FirstName=Yii::$app->user->identity->FirstName;
            $LastName=Yii::$app->user->identity->LastName;
            $model->UpdateBy=$FirstName." ".$LastName;
            $model->Updated_at=date('Y-m-d H:i:s');
            if(!empty($model->Cost)){
                $model->Profit=$model->SalePrice-$model->Cost;
            }          
            if($model->save()) {
                 Yii::$app->session->setFlash('success','Order Successfully Updated');
                 $back=\Yii::$app->session->get('user.backprocress');
                 $queryparam=\Yii::$app->session->get('user.queryparam');             
                 if(!empty($back)) {
                     if(!empty($queryparam['OrdersSearch'])) {
                          if(Yii::$app->user->identity->Role!='user') {                        
                          return $this->redirect([$back,"OrdersSearch[OrderDate]"=>$queryparam['OrdersSearch']['OrderDate'],
                                "OrdersSearch[OrderMainId]"=>$queryparam['OrdersSearch']['OrderMainId'],
                                "OrdersSearch[Quantity]"=>$queryparam['OrdersSearch']['Quantity'],
                                "OrdersSearch[Event]"=>$queryparam['OrdersSearch']['Event'],
                                "OrdersSearch[Venue]"=>$queryparam['OrdersSearch']['Venue'],
                                "OrdersSearch[Section]"=>$queryparam['OrdersSearch']['Section'],
                                "OrdersSearch[Row]"=>$queryparam['OrdersSearch']['Row'],
                                "OrdersSearch[EventDate]"=>$queryparam['OrdersSearch']['EventDate'],
                                "OrdersSearch[Cost]"=>$queryparam['OrdersSearch']['Cost'],
                                "OrdersSearch[SalePrice]"=>$queryparam['OrdersSearch']['SalePrice'],
                                "OrdersSearch[Profit]"=>$queryparam['OrdersSearch']['Profit'],
                                "OrdersSearch[Source]"=>$queryparam['OrdersSearch']['Source'], 
                                "OrdersSearch[CreditCard]"=>$queryparam['OrdersSearch']['CreditCard'], 
                                "OrdersSearch[Link]"=>$queryparam['OrdersSearch']['Link'], 
                                "OrdersSearch[Notes]"=>$queryparam['OrdersSearch']['Notes'], 
                                "OrdersSearch[Status]"=>$queryparam['OrdersSearch']['Status']]);
                          }else{
                            
                              return $this->redirect([$back,"OrdersSearch[OrderDate]"=>$queryparam['OrdersSearch']['OrderDate'],
                                "OrdersSearch[OrderMainId]"=>$queryparam['OrdersSearch']['OrderMainId'],
                                "OrdersSearch[Quantity]"=>$queryparam['OrdersSearch']['Quantity'],
                                "OrdersSearch[Event]"=>$queryparam['OrdersSearch']['Event'],
                                "OrdersSearch[Venue]"=>$queryparam['OrdersSearch']['Venue'],
                                "OrdersSearch[Section]"=>$queryparam['OrdersSearch']['Section'],
                                "OrdersSearch[Row]"=>$queryparam['OrdersSearch']['Row'],
                                "OrdersSearch[EventDate]"=>$queryparam['OrdersSearch']['EventDate'],
                                "OrdersSearch[Cost]"=>$queryparam['OrdersSearch']['Cost'],
                                "OrdersSearch[Source]"=>$queryparam['OrdersSearch']['Source'], 
                                "OrdersSearch[CreditCard]"=>$queryparam['OrdersSearch']['CreditCard'], 
                                  "OrdersSearch[Link]"=>$queryparam['OrdersSearch']['Link'], 
                                "OrdersSearch[Notes]"=>$queryparam['OrdersSearch']['Notes'],
                                "OrdersSearch[Status]"=>$queryparam['OrdersSearch']['Status']]);
                          }
                         
                      //                             
                   
                     }else{
                         return $this->redirect([$back]);
                     }
                 }else{
                      return $this->redirect(['buy']);
                 }
                // return $this->redirect(['view', 'id' => $model->OrderId]);
            }else{
                return $this->render('update', [
                'model' => $model,
                ]);
            }           
        } else {
            return $this->render('update', [
                'model' => $model,
            ]);
        }
    }

    /**
     * Deletes an existing Orders model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     */
    public function actionDelete($id)
    {
        $model=$this->findModel($id);
        if(!empty($model)) {
             $back=\Yii::$app->session->get('user.backprocress');
             if($model->Status=="TRASH") {
                 $model->Status="DELETED";
             }else{
                 $model->Status="TRASH";
             }
       // $model->Status="DELETED";
            if($model->save(false)){
                Yii::$app->session->setFlash('success','Order Successfully Deleted');
                 $back=\Yii::$app->session->get('user.backprocress');
                 $queryparam=\Yii::$app->session->get('user.queryparam');             
                 if(!empty($back)) {
                     if(!empty($queryparam['OrdersSearch'])) {
                          if(Yii::$app->user->identity->Role!='user') {                        
                          return $this->redirect([$back,"OrdersSearch[OrderDate]"=>$queryparam['OrdersSearch']['OrderDate'],
                                "OrdersSearch[OrderMainId]"=>$queryparam['OrdersSearch']['OrderMainId'],
                                "OrdersSearch[Quantity]"=>$queryparam['OrdersSearch']['Quantity'],
                                "OrdersSearch[Event]"=>$queryparam['OrdersSearch']['Event'],
                                "OrdersSearch[Venue]"=>$queryparam['OrdersSearch']['Venue'],
                                "OrdersSearch[Section]"=>$queryparam['OrdersSearch']['Section'],
                                "OrdersSearch[Row]"=>$queryparam['OrdersSearch']['Row'],
                                "OrdersSearch[EventDate]"=>$queryparam['OrdersSearch']['EventDate'],
                                "OrdersSearch[Cost]"=>$queryparam['OrdersSearch']['Cost'],
                                "OrdersSearch[SalePrice]"=>$queryparam['OrdersSearch']['SalePrice'],
                                "OrdersSearch[Profit]"=>$queryparam['OrdersSearch']['Profit'],
                                "OrdersSearch[Source]"=>$queryparam['OrdersSearch']['Source'], 
                                "OrdersSearch[CreditCard]"=>$queryparam['OrdersSearch']['CreditCard'],
                              "OrdersSearch[Link]"=>$queryparam['OrdersSearch']['Link'], 
                                "OrdersSearch[Notes]"=>$queryparam['OrdersSearch']['Notes'],
                                "OrdersSearch[Status]"=>$queryparam['OrdersSearch']['Status']]);
                          }else{
                            
                              return $this->redirect([$back,"OrdersSearch[OrderDate]"=>$queryparam['OrdersSearch']['OrderDate'],
                                "OrdersSearch[OrderMainId]"=>$queryparam['OrdersSearch']['OrderMainId'],
                                "OrdersSearch[Quantity]"=>$queryparam['OrdersSearch']['Quantity'],
                                "OrdersSearch[Event]"=>$queryparam['OrdersSearch']['Event'],
                                "OrdersSearch[Venue]"=>$queryparam['OrdersSearch']['Venue'],
                                "OrdersSearch[Section]"=>$queryparam['OrdersSearch']['Section'],
                                "OrdersSearch[Row]"=>$queryparam['OrdersSearch']['Row'],
                                "OrdersSearch[EventDate]"=>$queryparam['OrdersSearch']['EventDate'],
                                "OrdersSearch[Cost]"=>$queryparam['OrdersSearch']['Cost'],
                                "OrdersSearch[Source]"=>$queryparam['OrdersSearch']['Source'], 
                                "OrdersSearch[CreditCard]"=>$queryparam['OrdersSearch']['CreditCard'], 
                                  "OrdersSearch[Link]"=>$queryparam['OrdersSearch']['Link'], 
                                "OrdersSearch[Notes]"=>$queryparam['OrdersSearch']['Notes'],
                                "OrdersSearch[Status]"=>$queryparam['OrdersSearch']['Status']]);
                          }
                         
                      //                             
                   
                     }else{
                         return $this->redirect([$back]);
                     }
                 }else{
                      return $this->redirect(['buy']);
                 }
            }else{
               return $this->redirect(['buy']); 
            }
         //return $this->redirect(['index']);}
        }else{
             return $this->redirect(['buy']);
        }
    }

    /**
     * Finds the Orders model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return Orders the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id)
    {
        if (($model = Orders::findOne($id)) !== null) {
            return $model;
        } else {
            throw new NotFoundHttpException('The requested page does not exist.');
        }
    }
}